@@ -3,11 +3,7 @@
 See: 2.2.18.6, OBJREF_CUSTOM
 """
 import struct
-from ..dcom_const import CLSID_ActivationPropertiesIn
-from ..dcom_const import IID_IActivationPropertiesIn
-from ..dcom_const import FLAGS_OBJREF_CUSTOM
-from ..uuid import uuid_part, bin_to_str, CLSID_SZ
-from .const import FLAGS_OBJREF_STANDARD
+from ..uuid import bin_to_str, CLSID_SZ
 from .objref import ObjRef
 
 
